==> haskell-strict-list-0.1.7.6-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-list
version:              0.1.7.6
visibility:           public
id:                   strict-list-0.1.7.6-IePJ6xwzbuu9QAlzGPakyb
key:                  strict-list-0.1.7.6-IePJ6xwzbuu9QAlzGPakyb
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

category:             Data
abi:                  7554ee36afc279b6087c31f9da1c5596
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-list
hs-libraries:         HSstrict-list-0.1.7.6-IePJ6xwzbuu9QAlzGPakyb
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    semigroupoids-6.0.1-8qLN72ijylEEDKBod6y6Xy

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-strict-list-0.1.7.6-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-list
version:              0.1.7.6
visibility:           public
id:                   strict-list-0.1.7.6-5FV0NBufIEW9XXtr9EnqBQ
key:                  strict-list-0.1.7.6-5FV0NBufIEW9XXtr9EnqBQ
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

category:             Data
abi:                  5c8ad40b397d33f6a26db82abff83ccb
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-list
hs-libraries:         HSstrict-list-0.1.7.6-5FV0NBufIEW9XXtr9EnqBQ
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    semigroupoids-6.0.1-JylJMKNlBhVERdQrt2BAjT

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
